@@ -67,7 +67,7 @@ class HubzeroDatabaseConnection(object):
       file_read = open(docroot + '/configuration.php',"r")
       contents = file_read.read()
       file_read.close() 
-      for m in re.finditer("\s*var\s+\$([a-zA-Z-_0-9]+)\s*=\s*(.+)\s*;", contents):
+      for m in re.finditer("\s*(?:var|public)\s+\$([a-zA-Z-_0-9]+)\s*=\s*(.+)\s*;", contents):
         self.env.config.set('hubzero',m.group(1),m.group(2).strip(" \'\"\t"))
 
       mysql_host = self.env.config.get('hubzero', 'hzdb_host', self.env.config.get('hubzero', 'host', 'localhost'))
